@@ -1,4 +1,6 @@
-$:.unshift File.expand_path(File.join(File.dirname(__FILE__), 'lib'))
+# frozen_string_literal: true
+
+$LOAD_PATH.unshift File.expand_path(File.join(File.dirname(__FILE__), 'lib'))
 
 require 'puppetlabs_spec_helper/puppet_spec_helper'
 
