@@ -1,35 +1,30 @@
-require 'spec_helper'
-require 'puppetlabs_spec_helper/puppet_spec_helper'
-require 'puppetlabs_spec_helper/puppetlabs_spec/puppet_internals'
+# frozen_string_literal: true
 
-# reset mock integration
-RSpec.configure do |c|
-  c.mock_with :rspec
-end
+require 'spec_helper'
 
 describe PuppetlabsSpec::PuppetInternals do
-  before(:all) do
+  before(:all) do # this is only needed once # rubocop:disable RSpec/BeforeAfterAll
     Puppet.initialize_settings
   end
 
   describe '.scope' do
     let(:subject) { described_class.scope }
 
-    it 'should return a Puppet::Parser::Scope instance' do
+    it 'returns a Puppet::Parser::Scope instance' do
       expect(subject).to be_a_kind_of Puppet::Parser::Scope
     end
 
-    it 'should be suitable for function testing' do
+    it 'is suitable for function testing' do
       expect(subject.function_inline_template(['foo'])).to eq('foo')
     end
 
-    it 'should accept a compiler' do
+    it 'accepts a compiler' do
       compiler = described_class.compiler
       scope = described_class.scope(compiler: compiler)
       expect(scope.compiler).to eq(compiler)
     end
 
-    it 'should have a source set' do
+    it 'has a source set' do
       scope = subject
       expect(scope.source).not_to be_nil
       expect(scope.source.name).to eq('foo')
@@ -88,12 +83,12 @@ describe PuppetlabsSpec::PuppetInternals do
     it 'accepts an injected scope' do
       expect(Puppet::Parser::Functions).to receive(:function).with('my_func').and_return(true)
       scope = double(described_class.scope)
-      scope.expects(:method).with(:function_my_func).returns(:fake_method)
+      expect(scope).to receive(:method).with(:function_my_func).and_return(:fake_method)
       expect(described_class.function_method('my_func', scope: scope)).to eq(:fake_method)
     end
 
     it "returns nil if the function doesn't exist" do
-      Puppet::Parser::Functions.expects(:function).with('my_func').returns(false)
+      expect(Puppet::Parser::Functions).to receive(:function).with('my_func').and_return(false)
       scope = double(described_class.scope)
       expect(described_class.function_method('my_func', scope: scope)).to be_nil
     end
